@@ -110,8 +110,8 @@ class ArchimedesApi:  # pylint:disable=too-few-public-methods
             params_str = str(kwargs.get("params"))
             data_str = str(kwargs.get("data"))
             raise HTTPError(
-                f"API Error while requesting {url} with parameters {params_str} and data {data_str}: "
-                f"{error_message}"
+                f"API Error with status code {response.status_code} while requesting {url} with parameters "
+                f"{params_str} and data {data_str}: {error_message}"
             )
 
         logger.debug(
